pub fn load_sessions_by_key(keys: &[SessionKey]) -> Result<Vec<Session>>Expand description
Load only requested Cursor sessions from local Cursor chat metadata.
Unreadable or invalid matching meta.json files are skipped.
Errors
Returns an error when the Cursor session store cannot be enumerated.